/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package com.mycompany.prj3.webservicerest;

import com.mycompany.exception.ExceptionUtil;
import com.mycompany.prj3.beans.Project;
import java.util.List;
import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.NoResultException;
import javax.persistence.PersistenceContext;
import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.Response;
import org.apache.log4j.Logger;

/**
 *
 * @author thierry
 */
@Stateless
@Path("project")
public class ProjectResource  {
  
    private static final Logger logger = Logger.getLogger(ProjectResource.class);
    
    @PersistenceContext(unitName = "puBdProject")
    private EntityManager entityManager;
    
    public ProjectResource() {
    }
    
    @GET
    @Produces("text/xml")
    public Project getProject(@QueryParam("id") Long id) {
        logger.info("In getProject for id : " + id);
        Project project = null;
        try {
            project = entityManager.find(Project.class, id);
        } catch (NoResultException e) {
            logger.error("Exception catchee " + ExceptionUtil.displayException(e));
            throw new WebApplicationException(Response.Status.NOT_FOUND);
        }
        logger.info("Project name : " + (project != null ? project.getName() : "Pas de projet"));
        return project;
    }
    
    @POST
    @Consumes("text/xml")
    public void insertProject(Project project) {
        logger.info("In insertProject");
        try {
            entityManager.persist(project);
            logger.info("projectName=[" + project.getName() + "] id=" + project.getProjectId());
            logger.info("startDate=" + (project.getStartDate()!=null ? project.getStartDate() : "Pas de date"));
        } catch (Exception e) {
            logger.error("Exception catchee " + ExceptionUtil.displayException(e));
        }
    }
    
    @GET
    @Produces("text/xml")
    @Path("/all/")
    public List<Project> getProjects() {
        logger.info("In getProjects");
        List<Project> list = null;
        try {
            list = entityManager.createNamedQuery(Project.PROJECT_FIND_ALL_PROJECTS).getResultList();
            logger.info("Nombre de projet : " + (list != null ? list.size() : "0"));
        } catch (Exception e) {
            logger.error("Exception catchee " + ExceptionUtil.displayException(e));
        }
        
        return list;
    }
    
    @PUT
    @Consumes("text/xml")
    public void updateProject(Project project) {
        logger.info("In updateProject");
        try {
            entityManager.merge(project);
            logger.info("projectName=[" + project.getName() + "] id=" + project.getProjectId());
        } catch (Exception e) {
            logger.error("Exception catchee " + ExceptionUtil.displayException(e));
        }
    }
    
    @DELETE
    @Consumes("text/xml")
    public void deleteProject(@QueryParam("id") Long id) {
        logger.info("In deleteProject for id " + id);
        try {
            Project project = entityManager.find(Project.class, id);
            logger.info("projectName=[" + project.getName() + "] id=" + project.getProjectId());
            entityManager.remove(project);
        } catch (Exception e) {
            logger.error("Exception catchee " + ExceptionUtil.displayException(e));
        }
    }
}
